@@ -2,8 +2,8 @@
 
 # Generic tasks
 from .basics import dump, glob, log, noop, sync, walk, write
-from .files import directory, rename_replace, strip_dirs
 from .filters import exclude, match
+from .paths import directory, relative_to, rename_replace, strip_dirs
 from .text import concat, contents_replace, footer, header, regex
 
 # Specific tasks
