@@ -125,7 +125,7 @@ class walk(Task):
     def __init__(self, *roots, relative=True):
         roots = list(map(Path, roots))
         for root in roots:
-            assert root.is_dir(), 'Must be a directory'
+            assert root.is_dir(), 'Directory not found: {}'.format(root)
         self.roots = roots
         self.relative = relative
 
