@@ -2,7 +2,11 @@ from ..core import Task
 
 
 class match(Task):
-    """Filters only matching files."""
+    """
+    Filters only matching files.
+
+    NOTE: Matching is done from the right.
+    """
 
     def __init__(self, pattern):
         self.pattern = pattern
@@ -14,7 +18,11 @@ class match(Task):
 
 
 class exclude(Task):
-    """Excludes matching files."""
+    """
+    Excludes matching files.
+
+    NOTE: Matching is done from the right.
+    """
 
     def __init__(self, pattern):
         self.pattern = pattern
